# pypushflow

A task scheduler for cyclic and acyclic graphs

## Install

```bash
python -m pip install pypushflow[mx]
```

Use the `mx` option for installation at MX beamlines.

## Run tests

```bash
python -m pip install pypushflow[test]
pytest
```
